# ----------------------------------------------------------------------
# Curses::UI::Language::polish
# Maintainer: akukula@interia.pl
# ----------------------------------------------------------------------

package Curses::UI::Language::polish; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Rozmiar twojego ekranu jest zbyt mały dla tej aplikacji.
Zmień rozmiar ekranu i uruchom ponownie aplikację.
NAciśnij <CTRL+C> aby zakończyć...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
Styczeń Luty Marzec Kwiecień Maj Czerwiec Lipiec 
Sierpień Wrzesień Październik Listopad Grudzień

[days_short] Ni Po Wt Śr Cz Pi So

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:OK
[button_cancel]  a:Anuluj
[button_yes]     t:Tak
[button_no]      n:Nie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Komunikat o błędzie

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Wybierz plik
[file_savetitle] Wybierz plik do zapisu
[file_loadtitle] Wybierz plik do odczytu

# The labels for the dialog screen.
[file_path]      Ścieżka :
[file_file]      Plik :
[file_mask]      Maska :

# The size of the longest label
[file_labelsize] 9

# On directory up
[file_dirup] Katalog nadrzędny

# For asking the user if a file may be overwritten
[file_overwrite_title] Potwierdzenie
[file_overwrite_question_pre] 
Plik "
[file_overwrite_question_post] 
" już istnieje. Czy chcesz zamienić istniejący plik?

# Errors
[file_err_opendir_pre] Nie można otworzyć katalogu "
[file_err_opendir_post] "
[file_err_nofileselected] Nie wybrano pliku!

